﻿using Microsoft.AspNetCore.Razor.TagHelpers;
using System.Collections.Generic;
using System.Text;
using System.Threading.Tasks;

namespace TagHelpersTutorial.Helpers
{
    public class AutoCompleteTagHelper : TagHelper
    {
        public string Id { get; set; }
        public string delay { get; set; }
        public override async void Process(TagHelperContext context, TagHelperOutput output)
        {
            output.TagName = "";
            StringBuilder sb = new StringBuilder();
            sb.AppendLine("<input id=\"" + Id + "\" />");
            sb.AppendLine("<script>");
            sb.AppendLine("$(\"#" + Id + "\").autocomplete({ delay:"+delay+",");

            var childContent = await output.GetChildContentAsync(); //get the ItemsSourceBinder content
            var source = childContent.GetContent();
            sb.Append(source);      // append the ItemsSourceBinder
            sb.AppendLine("});");
            sb.AppendLine("</script>");
            output.Content.SetHtmlContent(sb.ToString()); //process the output
        }

        public override Task ProcessAsync(TagHelperContext context, TagHelperOutput output)
        {
            return base.ProcessAsync(context, output);
        }
    }

    [HtmlTargetElement("items-source")]
    public class ItemsSourceBinderTagHelper : TagHelper
    {
        public List<string> Source { get; set; }

        public override void Process(TagHelperContext context, TagHelperOutput output)
        {
            output.TagName = "";
            StringBuilder sb = new StringBuilder();
            if (Source != null && Source.Count > 0)
            {
                sb.AppendLine("source:");
                sb.Append("[");
                for (int i = 0; i <= Source.Count - 1; i++)
                {
                    sb.Append(i == 0 ? "\"" + Source[i].ToString() + "\"" : ", \"" + Source[i].ToString() + "\"");

                }
                sb.Append("]");
            }
            output.Content.AppendHtml(sb.ToString());
        }
    }

   
}

