﻿using Microsoft.AspNetCore.Razor.Runtime.TagHelpers;
using Microsoft.AspNetCore.Razor.TagHelpers;
using System.Text;
using TagHelpersTutorial.Models;
namespace TagHelpersTutorial.Helpers
{
    //define the parent taghelper
    public class ContactTagHelper : TagHelper
    {
        public string Name
        {
            get { return Contact.Name; }
            set { Contact.Name = value; }
        }


        private Company _contact;
        private Company Contact
        {
            get
            {
                return _contact ?? (_contact = new Company());
            }
            set
            {
                _contact = value;
            }
        }
        public override async void Process(TagHelperContext context, TagHelperOutput output)
        {

            //In taghelper, we can transfer some information to its children taghelpers via context.Items.
            //The children taghelpers will get a copy of its parent's Items. 

            // here we can save some information. Its children tags can obtain this information.
            context.Items["Parent"] = Contact;
            // render the children taghelpers. This is necessary to await since we need location info to render.
            TagHelperContent locationContent = await output.GetChildContentAsync();

            var loc = context.Items["Parent"] as Company;
            StringBuilder sb = new StringBuilder();
            string str = string.Format(@"<div>
           <text id=""txtName"">{0}</text><br/>          
             <text  id=""txtCity""/>{2}</text>, <text  id=""txtCountry""  />{1}</text><br/>     
               <text  id=""txtPhone""  />Ph:{3}</text>     
            </div>", Name, loc.Location.Country, loc.Location.City, loc.Location.Phone);
            sb.Append(str);
            output.Content.AppendHtml(sb.ToString());
            // when we get all the information from children taghelpers, 
            // the we can render the html markup and startup scripts.
        }
    }

    // define the nested tag: location
    public class LocationTagHelper : TagHelper
    {
        public string Country { get; set; }
        public string City { get; set; }
        public string Phone { get; set; }

        public override void Process(TagHelperContext context, TagHelperOutput output)
        {
            // Get the information from its parent tag.
            var parent = context.Items["Parent"] as Company;
            // set its attributes' values to some instance from the parent.
            parent.Location.Country = Country;
            parent.Location.City = City;
            parent.Location.Phone = Phone;
            // save some information so that its children taghelpers can use.
            context.Items["Parent"] = parent.Location;
            // render the children taghelpers
            output.GetChildContentAsync();


        }
    }


}